<?php

namespace Drupal\l2j_connect\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure L2J Connect settings for this site.
 */
class L2JConnectSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'l2j_connect_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['l2j_connect.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['l2j_connect_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('L2J Configuration')
    ];
    $form['l2j_connect_settings']['loginserver'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Login server')
    ];
    $form['l2j_connect_settings']['loginserver']['login_server_host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Login server host'),
      '#default_value' => $this->config('l2j_connect.settings')->get('login_server_host')
    ];
    $form['l2j_connect_settings']['loginserver']['login_server_database'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Login server database'),
      '#default_value' => $this->config('l2j_connect.settings')->get('login_server_database')
    ];
    $form['l2j_connect_settings']['loginserver']['login_server_user'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Login server user'),
      '#default_value' => $this->config('l2j_connect.settings')->get('login_server_user')
    ];
    $form['l2j_connect_settings']['loginserver']['login_server_password'] = [
      '#type' => 'password',
      '#title' => $this->t('Login server password'),
      '#default_value' => $this->config('l2j_connect.settings')->get('login_server_password')
    ];
    $form['l2j_connect_settings']['gameserver'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Game server')
    ];
    $form['l2j_connect_settings']['gameserver']['game_server_host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Game server host'),
      '#default_value' => $this->config('l2j_connect.settings')->get('login_server_host')
    ];
    $form['l2j_connect_settings']['gameserver']['game_server_database'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Game server database'),
      '#default_value' => $this->config('l2j_connect.settings')->get('game_server_database')
    ];
    $form['l2j_connect_settings']['gameserver']['game_server_user'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Game server user'),
      '#default_value' => $this->config('l2j_connect.settings')->get('game_server_user')
    ];
    $form['l2j_connect_settings']['gameserver']['game_server_password'] = [
      '#type' => 'password',
      '#title' => $this->t('Game server password'),
      '#default_value' => $this->config('l2j_connect.settings')->get('game_server_password')
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('l2j_connect.settings')
      ->set('login_server_host', $form_state->getValue('login_server_host'))
      ->set('login_server_database', $form_state->getValue('login_server_database'))
      ->set('login_server_user', $form_state->getValue('login_server_user'))
      ->set('login_server_password', $form_state->getValue('login_server_password'))
      ->set('game_server_host', $form_state->getValue('game_server_host'))
      ->set('game_server_database', $form_state->getValue('game_server_database'))
      ->set('game_server_user', $form_state->getValue('game_server_user'))
      ->set('game_server_password', $form_state->getValue('game_server_password'))
      ->save();
  }

}
