<?php

namespace Drupal\l2jserver\Service;

use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

class L2JConnectService {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * @param \Drupal\Core\Database\Connection $database
   *  The database connection.
   */
  public function __construct(Connection $database) {
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * Check if a given account exists in L2j loginserver.
   */
  private function l2j_connect_login_exists($login) {
    $exists = FALSE;
    if (!l2j_connect_check_db('loginserver')) {
      return $exists;
    }
    \Drupal\Core\Database\Database::getActiveConnection('loginserver');
    $result = db_query('SELECT login from {accounts} WHERE login=:login', [':login' => $login]);
    \Drupal\Core\Database\Database::getActiveConnection();
    return !empty($result);
  }

  /**
   * Check if a given email exists in L2j loginserver.
   */
  private function l2j_connect_mail_exists($mail) {
    $exists = FALSE;
    if (!l2j_connect_check_db('loginserver')) {
      return $exists;
    }
    \Drupal\Core\Database\Database::getActiveConnection('loginserver');
    $result = db_query('SELECT email from {accounts} WHERE email=@mail', ['@mail' => $mail]);
    \Drupal\Core\Database\Database::getActiveConnection();
    return !empty($result);
  }

  /**
   * Retrieve the mail info with an account as parameter from L2j loginserver.
   */
  public function l2j_connect_retrieve_mail($login) {
    if (!l2j_connect_check_db('loginserver')) {
      return FALSE;
    }
    \Drupal\Core\Database\Database::getActiveConnection('loginserver');
    $result = db_query('SELECT email from {accounts} WHERE login=:login', [':login' => $login])->fetchField();
    \Drupal\Core\Database\Database::getActiveConnection();
    return $result;
  }

  /**
   * Retrieve the login info with an email as parameter from L2j loginserver.
   */
  public function l2j_connect_retrieve_login($mail) {
    if (!l2j_connect_check_db('loginserver')) {
      return FALSE;
    }
    \Drupal\Core\Database\Database::getActiveConnection('loginserver');
    $result = db_query('SELECT login from {accounts} WHERE email=:email',  [':email' => $mail])->fetchField();
    \Drupal\Core\Database\Database::getActiveConnection();
    return $result;
  }

  /**
   * Check if an L2j account exists in L2j loginserver.
   */
  public function l2j_connect_account_exists($login, $email) {
    \Drupal\Core\Database\Database::getActiveConnection('loginserver');
    $result = db_query('SELECT login, email from {accounts} WHERE login=:login AND email=:email', [':login' => $login, ':email' => $email]);
    \Drupal\Core\Database\Database::getActiveConnection();
    return !empty($result);
  }

  //  /**
  //   * Log in L2j loginserver with a given username and password.
  //   */
  //  private function l2j_connect_account_loggin_in($username, $password) {
  //    $exists = TRUE;
  //    if (l2j_connect_check_db('loginserver')) {
  //      \Drupal\Core\Database\Database::getActiveConnection('loginserver');
  //      $result = db_query('SELECT login, password, accessLevel from {accounts} WHERE login=:login AND password=:password AND accessLevel >= 0', [':login' => $username, ':password' => l2j_connect_encrypt($password)]);
  //      $exists = !empty($result);
  //      \Drupal\Core\Database\Database::getActiveConnection();
  //    }
  //    return $exists;
  //  }

  //  /**
  //   * Create an external account in L2j loginserver.
  //   */
  //  private function l2j_connect_external_create_account($account) {
  //    if (l2j_connect_check_db('loginserver')) {
  //      \Drupal\Core\Database\Database::getActiveConnection('loginserver');
  //      $result = db_insert('accounts')
  //        ->fields([
  //          'login' => $account->login,
  //          'password' => l2j_connect_encrypt($account->pass),
  //          'email' => $account->mail,
  //          'accessLevel' => $account->access
  //        ]);
  //        $result->execute();
  //      \Drupal\Core\Database\Database::getActiveConnection();
  //      drupal_set_message(t('The Account has been created in the Loginserver database.'), 'status');
  //    }
  //    return TRUE;
  //  }

  /**
   * Checks if the settings have currently defined the loginserver connection.
   * (deprecated)
   */
  public function l2j_connect_check_db($name) {
    global $databases;
    return !isset($databases[$name]);
  }

  /**
   * Encrypt a password to match the current L2j loginserver encrypt method.
   */
  protected function l2j_connect_encrypt($pass) {
    return base64_encode(pack("H*", sha1(utf8_encode($pass))));
  }

}
