<?php 

namespace Drupal\l2j_connect\Twig;

use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;
use Drupal\l2j_connect\Service\L2JConnectService;

/**
 * L2JConnectTwig class.
 *
 */
class L2JConnectTwig extends AbstractExtension {

  /**
   * L2J Connect service.
   *
   * @var \Drupal\l2j_connect\Service\L2JConnectService;
   */
  protected $l2jConnectService;

  /**
   * Constructor
   * @param L2JConnectService $l2jConnectService
   */
  public function __construct(L2JConnectService $l2jConnectService) {
    $this->l2jConnectService = $l2jConnectService;
  }

  /**
   * Get extension twig function
   * @return array
   */
  public function getFunctions() {
    return [
      new TwigFunction('is_game_server_up', [$this, 'isGameServerUp']),
      new TwigFunction('is_login_server_up', [$this, 'isLoginServerUp']),
      new TwigFunction('has_owner', [$this, 'hasOwner']),
    ];
  }

  /**
   * Is game server up
   * @return boolean
   */
  public function isGameServerUp() {
    return $this->l2jConnectService->isGameServerUp();
  }

  /**
   * Is login server up
   * @return boolean
   */
  public function isLoginServerUp() {
    return $this->l2jConnectService->isLoginServerUp();
  }
  
  /**
   * Small owner check
   * @param string $name is[Gludio|Dion|Giran|Goddard|Aden|Rune|Schuttgart|Conquerable|Clanhall|AnyName|....]
   * @return string
   */
  public function owner($name) {
     $methodName = 'has' . (string) $name;
     return $this->l2jConnectService->$methodName();
  }
  
  /**
   * Extension name
   * @return string
   */
  public function getName() {
    return 'l2j_connect.twig.extension';
  }

}